@@ -7,7 +7,7 @@ from lunar.config import Config
 from lunar.lunar_client import LunarClient, LunarError
 from lunar.rec.channels.models import Channel, ChannelPutIn, ChannelPatchIn
 
-LUNAR_CHANNELS_API_URL = "/v1/channels"
+LUNAR_REC_CHANNELS_API_URL = "/v1/channels"
 
 loop = asyncio.get_event_loop()
 
@@ -28,7 +28,7 @@ class ChannelClient(LunarClient):
     def __init__(self, config: Config):
         super().__init__(config)
 
-        self.api_url = LUNAR_CHANNELS_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_CHANNELS_API_URL}"
+        self.api_url = LUNAR_REC_CHANNELS_API_URL if config.ENV == "LOCAL" else f"/api{LUNAR_REC_CHANNELS_API_URL}"
 
     async def create_channel_async(self, id: str, experiment_id: str = None) -> Channel:
         """
